@@ -1,7 +1,7 @@
 package Complete::Util;
 
-our $DATE = '2015-04-02'; # DATE
-our $VERSION = '0.27'; # VERSION
+our $DATE = '2015-04-25'; # DATE
+our $VERSION = '0.28'; # VERSION
 
 use 5.010001;
 use strict;
@@ -440,6 +440,9 @@ a directory, or a module name. You can do something like this:
         complete_module(word=>$word, ci=>1),
     );
 
+If a completion answer has a metadata `final` set to true, then that answer is
+used as the final answer without any combining with the other answers.
+
 _
     args => {
         answers => {
@@ -489,11 +492,18 @@ sub combine_answers {
         }
     };
 
+  ANSWER:
     for my $ans (@_) {
         if (ref($ans) eq 'ARRAY') {
             $add_words->($ans);
         } elsif (ref($ans) eq 'HASH') {
             $encounter_hash++;
+
+            if ($ans->{final}) {
+                $final = $ans;
+                last ANSWER;
+            }
+
             $add_words->($ans->{words} // []);
             for (keys %$ans) {
                 if ($_ eq 'words') {
@@ -532,7 +542,7 @@ Complete::Util - General completion routine
 
 =head1 VERSION
 
-This document describes version 0.27 of Complete::Util (from Perl distribution Complete-Util), released on 2015-04-02.
+This document describes version 0.28 of Complete::Util (from Perl distribution Complete-Util), released on 2015-04-25.
 
 =head1 DESCRIPTION
 
@@ -571,6 +581,9 @@ a directory, or a module name. You can do something like this:
      complete_module(word=>$word, ci=>1),
  );
 
+If a completion answer has a metadata C<final> set to true, then that answer is
+used as the final answer without any combining with the other answers.
+
 Arguments ('*' denotes required arguments):
 
 =over 4
